From cb481d835299178b2d1da858e11bc24e715167d2 Mon Sep 17 00:00:00 2001
From: Barun Parruck <barun.parruck@gmail.com>
Date: Tue, 8 Mar 2016 20:59:35 +0530
Subject: [PATCH 2/2] Restores settings to default values on closing project

The settings were not restored when the project is closed.
A method was thus exposed in settings to reassign the settings to their default values.
---
 src/Project/Project.cpp   |  2 +-
 src/Settings/Settings.cpp | 13 ++++++++++++-
 src/Settings/Settings.h   |  1 +
 3 files changed, 14 insertions(+), 2 deletions(-)

diff --git a/src/Project/Project.cpp b/src/Project/Project.cpp
index dee00e9..0401154 100644
--- a/src/Project/Project.cpp
+++ b/src/Project/Project.cpp
@@ -266,7 +266,7 @@ Project::closeProject()
 {
     if ( m_projectFile == nullptr )
         return;
-    // FIXME: Restore settings to their default value
+    m_settings->restoreDefaultValues();
     emit projectClosed();
     delete m_projectFile;
     m_projectFile = nullptr;
diff --git a/src/Settings/Settings.cpp b/src/Settings/Settings.cpp
index 2259228..70f795e 100644
--- a/src/Settings/Settings.cpp
+++ b/src/Settings/Settings.cpp
@@ -164,7 +164,18 @@ Settings::setValue(const QString &key, const QVariant &value)
     Q_ASSERT_X( false, __FILE__, "setting value without a created variable" );
     return false;
 }
-
+bool
+Settings::restoreDefaultValues()
+{
+    auto begin = m_settings.begin();
+    auto end   = m_settings.end();
+    for ( ; begin!=end ; ++begin )
+    {
+        (*begin)->restoreDefault();
+        return true;
+    }
+    return false;
+}
 SettingValue*
 Settings::value(const QString &key)
 {
diff --git a/src/Settings/Settings.h b/src/Settings/Settings.h
index 65d368a..a732987 100644
--- a/src/Settings/Settings.h
+++ b/src/Settings/Settings.h
@@ -122,6 +122,7 @@ class   Settings : public ILoadSave
         bool                        load();
         bool                        save();
         bool                        save( QXmlStreamWriter& project );
+        bool                        restoreDefaultValues();
         void                        setSettingsFile( const QString& settingsFile );
 
         bool                        load( const QDomDocument& document );
-- 
2.3.2 (Apple Git-55)

